define("slmdx/util/slmUtil", [
         "dojo/_base/lang",
         "xcitec/_base/Date",
         "xcitec/_base/wiky"
       ], function (lang, Date, Wiky) {
  /*=====
   xcitecUtil = {
   // summary:
   //     Utilities for slmui
   };
   =====*/

  function str2obj (/*String*/ value, /*String*/ type){
    // summary:
    //		Convert given string value to given type
    //NOTE: copy from dojo.parser.str2obj
    var d = dojo;
    switch(type){
    case "string":
      return value;
    case "number":
      return value.length ? Number(value) : NaN;
    case "boolean":
      // for checked/disabled value might be "" or "checked".	 interpret as true.
      return typeof value == "boolean" ? value : !(value.toLowerCase()=="false");
    case "function":
      if(d.isFunction(value)){
        // IE gives us a function, even when we say something like onClick="foo"
        // (in which case it gives us an invalid function "function(){ foo }").
        //	Therefore, convert to string
        value=value.toString();
        value=d.trim(value.substring(value.indexOf('{')+1, value.length-1));
      }
      try{
        if(value === "" || value.search(/[^\w\.]+/i) != -1){
          // The user has specified some text for a function like "return x+5"
          return new Function(value);
        }else{
          // The user has specified the name of a function like "myOnClick"
          // or a single word function "return"
          return d.getObject(value, false) || new Function(value);
        }
      }catch(e){ return new Function(); }
    case "array":
      return value ? value.split(/\s*,\s*/) : [];
    case "date":
      switch(value){
      case "": return new Date("");	// the NaN of dates
      case "now": return new Date();	// current date
      default: return d.date.stamp.fromISOString(value);
      }
    case "url":
      return d.baseUrl + value;
    default:
      return d.fromJson(value);
    }
  }

  function decodeHTMLEntities(encodedVal) {
	var tempTextarea = document.createElement('textarea');
	tempTextarea.innerHTML = encodedVal;
	return tempTextarea.value;
  } 
  
  return {
    str2obj : str2obj,
	decodeHTMLEntities: decodeHTMLEntities,
	
    str2bool: function(/*String*/ value){
      //if (value==null) return false;
      //return xcitecUtil.str2obj( value, "boolean");
      return (value != null) && str2obj(value, "boolean");
      // for "selected" IE8 returns empty string if attribut "selected" is not defined.
      // fix was wrong under FF it returns empty string if just attribut "selected" is defined
      //return value && (value!=null) && xcitecUtil.str2obj( value, "boolean");
    },

    escapeXml: function(/*String*/ str, /*Boolean?*/ noSingleQuotes){
      // summary:
      //		Adds escape sequences for special characters in XML: &<>"'
      //		Optionally skips escapes for single quotes
      //
      if(!str) return str;
      str = str.replace(/&/gm, "&amp;")
          .replace(/</gm, "&lt;")
          .replace(/>/gm, "&gt;")
          .replace(/"/gm, "&quot;")
          .replace(/'/gm, "&#39;");
      //	if(!noSingleQuotes){
      //		str = str.replace(/'/gm, "&#39;");
      //	}
      return str; // string
    },

    createTypedStyleClass: function(/*String*/ baseStyleClass, /*String*/ styleType){
      return baseStyleClass + styleType.charAt(0).toUpperCase() + styleType.substr(1).replace(/-.*/, "");
    },

    createEntityIconClass: function(/*String*/ entityClass){
      if(!entityClass) return entityClass;
      return "sboIcon" + entityClass.charAt(0).toUpperCase() + entityClass.substr(1);
    },

    parseDate: function(Input, Mask, Default){
      return Date.parseFormat(Input, Mask.toUpperCase(), Default);
    },

    toHtml: function(text){
      return Wiky.toHtml(text);
    },

    processLabelAdminClick: function(labelId){
      if(typeof this.onLabelAdminClick == "function"){
        return this.onLabelAdminClick(labelId);
      }
    },

	isValidEmail: function(value){
		// user name RE per rfc5322
		var usernameRE = "([!#-'*+\\-\\/-9=?A-Z^-~]+[.])*[!#-'*+\\-\\/-9=?A-Z^-~]+";

		// Domain name labels can not end with a dash.
		var domainLabelRE = "(?:[\\da-zA-Z](?:[-\\da-zA-Z]{0,61}[\\da-zA-Z])?)";
		var domainNameRE = "(?:[a-zA-Z](?:[-\\da-zA-Z]{0,6}[\\da-zA-Z])?)";


		// decimal-dotted IP address RE.
		var dottedDecimalRE =
			// Each number is between 0-255.  Zero padding is not allowed.
			"((\\d|[1-9]\\d|1\\d\\d|2[0-4]\\d|25[0-5])\\.){3}(\\d|[1-9]\\d|1\\d\\d|2[0-4]\\d|25[0-5])";

		// dotted hex IP address RE.  Each number is between 0x0-0xff.  Zero padding is allowed, e.g. 0x00.
		var dottedHexRE = "(0[xX]0*[\\da-fA-F]?[\\da-fA-F]\\.){3}0[xX]0*[\\da-fA-F]?[\\da-fA-F]";

		// dotted octal IP address RE.  Each number is between 0000-0377.
		// Zero padding is allowed, but each number must have at least 4 characters.
		var dottedOctalRE = "(0+[0-3][0-7][0-7]\\.){3}0+[0-3][0-7][0-7]";

		// decimal IP address RE.  A decimal number between 0-4294967295.
		var decimalRE =  "(0|[1-9]\\d{0,8}|[1-3]\\d{9}|4[01]\\d{8}|42[0-8]\\d{7}|429[0-3]\\d{6}|" +
			"4294[0-8]\\d{5}|42949[0-5]\\d{4}|429496[0-6]\\d{3}|4294967[01]\\d{2}|42949672[0-8]\\d|429496729[0-5])";

		// hexadecimal IP address RE.
		// A hexadecimal number between 0x0-0xFFFFFFFF. Case insensitive.  Zero padding is allowed.
		var hexRE = "0[xX]0*[\\da-fA-F]{1,8}";

		// IPv6 address RE.
		// The format is written as eight groups of four hexadecimal digits, x:x:x:x:x:x:x:x,
		// where x is between 0000-ffff. Zero padding is optional. Case insensitive.
		var ipv6RE = "([\\da-fA-F]{1,4}\\:){7}[\\da-fA-F]{1,4}";

		// IPv6/IPv4 Hybrid address RE.
		// The format is written as six groups of four hexadecimal digits,
		// followed by the 4 dotted decimal IPv4 format. x:x:x:x:x:x:d.d.d.d
		var hybridRE = "([\\da-fA-F]{1,4}\\:){6}" +
			"((\\d|[1-9]\\d|1\\d\\d|2[0-4]\\d|25[0-5])\\.){3}(\\d|[1-9]\\d|1\\d\\d|2[0-4]\\d|25[0-5])";

		// Build IP Address RE
		var a = [];
		a.push(dottedDecimalRE);
		a.push(dottedHexRE);
		a.push(dottedOctalRE);
		a.push(decimalRE);
		a.push(hexRE);
		a.push(ipv6RE);
		a.push(hybridRE);

		var ipAddressRE = "(" + a.join("|") + ")";

		// build host RE
		var hostNameRE = "(((?:" + domainLabelRE + "\\.)+" + domainNameRE + "\\.?))|" + ipAddressRE;

		// build emailAddress RE
		var emailAddressRE = usernameRE + "@" + hostNameRE;

		var re = new RegExp("^" + emailAddressRE + "$", "i");
		return re.test(value);
	}
  };
});
